EXPORTS
	??0COmxInputPort@@IAE@XZ @ 1 NONAME ; COmxInputPort::COmxInputPort(void)
	??0COmxOutputPort@@IAE@XZ @ 2 NONAME ; COmxOutputPort::COmxOutputPort(void)
	??0COmxProcessingUnit@@IAE@XZ @ 3 NONAME ; COmxProcessingUnit::COmxProcessingUnit(void)
	??1COmxInputPort@@MAE@XZ @ 4 NONAME ; COmxInputPort::~COmxInputPort(void)
	??1COmxOutputPort@@MAE@XZ @ 5 NONAME ; COmxOutputPort::~COmxOutputPort(void)
	??1COmxProcessingUnit@@UAE@XZ @ 6 NONAME ; COmxProcessingUnit::~COmxProcessingUnit(void)
	?AddInputPort@COmxProcessingUnit@@IAEHPAVMMdfInputPort@@@Z @ 7 NONAME ; int COmxProcessingUnit::AddInputPort(class MMdfInputPort *)
	?AddOutputPort@COmxProcessingUnit@@IAEHPAVMMdfOutputPort@@@Z @ 8 NONAME ; int COmxProcessingUnit::AddOutputPort(class MMdfOutputPort *)
	?Component@COmxInputPort@@IBEPAVCOmxProcessingUnit@@XZ @ 9 NONAME ; class COmxProcessingUnit * COmxInputPort::Component(void) const
	?Component@COmxOutputPort@@IBEPAVCOmxProcessingUnit@@XZ @ 10 NONAME ; class COmxProcessingUnit * COmxOutputPort::Component(void) const
	?Configure@COmxProcessingUnit@@UAEHABVTPuConfig@@@Z @ 11 NONAME ; int COmxProcessingUnit::Configure(class TPuConfig const &)
	?ConstructL@COmxInputPort@@IAEXHPAVCOmxProcessingUnit@@@Z @ 12 NONAME ; void COmxInputPort::ConstructL(int, class COmxProcessingUnit *)
	?ConstructL@COmxOutputPort@@IAEXHPAVCOmxProcessingUnit@@@Z @ 13 NONAME ; void COmxOutputPort::ConstructL(int, class COmxProcessingUnit *)
	?ConstructL@COmxProcessingUnit@@IAEXABVTDesC8@@ABVMMdfProcessingUnitObserver@@@Z @ 14 NONAME ; void COmxProcessingUnit::ConstructL(class TDesC8 const &, class MMdfProcessingUnitObserver const &)
	?Create@COmxProcessingUnit@@UAEHABVMMdfProcessingUnitObserver@@@Z @ 15 NONAME ; int COmxProcessingUnit::Create(class MMdfProcessingUnitObserver const &)
	?CreateCustomInterface@COmxProcessingUnit@@UAEHVTUid@@@Z @ 16 NONAME ; int COmxProcessingUnit::CreateCustomInterface(class TUid)
	?CustomInterface@COmxProcessingUnit@@UAEPAXVTUid@@@Z @ 17 NONAME ; void * COmxProcessingUnit::CustomInterface(class TUid)
	?Execute@COmxProcessingUnit@@UAEXXZ @ 18 NONAME ; void COmxProcessingUnit::Execute(void)
	?GetConfig@COmxProcessingUnit@@UAEHAAVTPuConfig@@@Z @ 19 NONAME ; int COmxProcessingUnit::GetConfig(class TPuConfig &)
	?GetInputPorts@COmxProcessingUnit@@UAEHAAV?$RPointerArray@VMMdfInputPort@@@@@Z @ 20 NONAME ; int COmxProcessingUnit::GetInputPorts(class RPointerArray<class MMdfInputPort> &)
	?GetOutputPorts@COmxProcessingUnit@@UAEHAAV?$RPointerArray@VMMdfOutputPort@@@@@Z @ 21 NONAME ; int COmxProcessingUnit::GetOutputPorts(class RPointerArray<class MMdfOutputPort> &)
	?Initialize@COmxProcessingUnit@@UAEXXZ @ 22 NONAME ; void COmxProcessingUnit::Initialize(void)
	?MipBufferSize@COmxInputPort@@UBEKXZ @ 23 NONAME ; unsigned long COmxInputPort::MipBufferSize(void) const
	?MipConfigure@COmxInputPort@@UAEHABVTPuConfig@@@Z @ 24 NONAME ; int COmxInputPort::MipConfigure(class TPuConfig const &)
	?MipCreateBuffer@COmxInputPort@@UAEPAVCMMFBuffer@@H@Z @ 25 NONAME ; class CMMFBuffer * COmxInputPort::MipCreateBuffer(int)
	?MipCreateCustomInterface@COmxInputPort@@UAEHVTUid@@@Z @ 26 NONAME ; int COmxInputPort::MipCreateCustomInterface(class TUid)
	?MipCustomInterface@COmxInputPort@@UAEPAXVTUid@@@Z @ 27 NONAME ; void * COmxInputPort::MipCustomInterface(class TUid)
	?MipDisconnectTunnel@COmxInputPort@@UAEXXZ @ 28 NONAME ; void COmxInputPort::MipDisconnectTunnel(void)
	?MipFreeBuffer@COmxInputPort@@UAEHPAVCMMFBuffer@@@Z @ 29 NONAME ; int COmxInputPort::MipFreeBuffer(class CMMFBuffer *)
	?MipGetConfig@COmxInputPort@@UAEHAAVTPuConfig@@@Z @ 30 NONAME ; int COmxInputPort::MipGetConfig(class TPuConfig &)
	?MipIndex@COmxInputPort@@UBEHXZ @ 31 NONAME ; int COmxInputPort::MipIndex(void) const
	?MipInitialize@COmxInputPort@@UAEXXZ @ 32 NONAME ; void COmxInputPort::MipInitialize(void)
	?MipIsTunnelled@COmxInputPort@@UBEHXZ @ 33 NONAME ; int COmxInputPort::MipIsTunnelled(void) const
	?MipRestartTunnel@COmxInputPort@@UAEXXZ @ 34 NONAME ; void COmxInputPort::MipRestartTunnel(void)
	?MipSetObserver@COmxInputPort@@UAEXABVMMdfInputPortObserver@@@Z @ 35 NONAME ; void COmxInputPort::MipSetObserver(class MMdfInputPortObserver const &)
	?MipTunnelRequest@COmxInputPort@@UAEHABVMMdfOutputPort@@AAW4TTunnelFlags@@AAW4TSupplierType@@@Z @ 36 NONAME ; int COmxInputPort::MipTunnelRequest(class MMdfOutputPort const &, enum TTunnelFlags &, enum TSupplierType &)
	?MipUseBuffer@COmxInputPort@@UAEHAAVCMMFBuffer@@@Z @ 37 NONAME ; int COmxInputPort::MipUseBuffer(class CMMFBuffer &)
	?MipWriteData@COmxInputPort@@UAEXAAVCMMFBuffer@@@Z @ 38 NONAME ; void COmxInputPort::MipWriteData(class CMMFBuffer &)
	?MopBufferSize@COmxOutputPort@@UBEKXZ @ 39 NONAME ; unsigned long COmxOutputPort::MopBufferSize(void) const
	?MopConfigure@COmxOutputPort@@UAEHABVTPuConfig@@@Z @ 40 NONAME ; int COmxOutputPort::MopConfigure(class TPuConfig const &)
	?MopCreateBuffer@COmxOutputPort@@UAEPAVCMMFBuffer@@H@Z @ 41 NONAME ; class CMMFBuffer * COmxOutputPort::MopCreateBuffer(int)
	?MopCreateCustomInterface@COmxOutputPort@@UAEHVTUid@@@Z @ 42 NONAME ; int COmxOutputPort::MopCreateCustomInterface(class TUid)
	?MopCustomInterface@COmxOutputPort@@UAEPAXVTUid@@@Z @ 43 NONAME ; void * COmxOutputPort::MopCustomInterface(class TUid)
	?MopDisconnectTunnel@COmxOutputPort@@UAEXXZ @ 44 NONAME ; void COmxOutputPort::MopDisconnectTunnel(void)
	?MopFreeBuffer@COmxOutputPort@@UAEHPAVCMMFBuffer@@@Z @ 45 NONAME ; int COmxOutputPort::MopFreeBuffer(class CMMFBuffer *)
	?MopGetConfig@COmxOutputPort@@UAEHAAVTPuConfig@@@Z @ 46 NONAME ; int COmxOutputPort::MopGetConfig(class TPuConfig &)
	?MopIndex@COmxOutputPort@@UBEHXZ @ 47 NONAME ; int COmxOutputPort::MopIndex(void) const
	?MopInitialize@COmxOutputPort@@UAEXXZ @ 48 NONAME ; void COmxOutputPort::MopInitialize(void)
	?MopIsTunnelled@COmxOutputPort@@UBEHXZ @ 49 NONAME ; int COmxOutputPort::MopIsTunnelled(void) const
	?MopReadData@COmxOutputPort@@UAEXAAVCMMFBuffer@@@Z @ 50 NONAME ; void COmxOutputPort::MopReadData(class CMMFBuffer &)
	?MopRestartTunnel@COmxOutputPort@@UAEXXZ @ 51 NONAME ; void COmxOutputPort::MopRestartTunnel(void)
	?MopSetObserver@COmxOutputPort@@UAEXABVMMdfOutputPortObserver@@@Z @ 52 NONAME ; void COmxOutputPort::MopSetObserver(class MMdfOutputPortObserver const &)
	?MopTunnelRequest@COmxOutputPort@@UAEHABVMMdfInputPort@@AAW4TTunnelFlags@@AAW4TSupplierType@@@Z @ 53 NONAME ; int COmxOutputPort::MopTunnelRequest(class MMdfInputPort const &, enum TTunnelFlags &, enum TSupplierType &)
	?MopUseBuffer@COmxOutputPort@@UAEHAAVCMMFBuffer@@@Z @ 54 NONAME ; int COmxOutputPort::MopUseBuffer(class CMMFBuffer &)
	?MopcEventHandler@COmxProcessingUnit@@UAEHPAXW4OMX_EVENTTYPE@@KK0@Z @ 55 NONAME ; int COmxProcessingUnit::MopcEventHandler(void *, enum OMX_EVENTTYPE, unsigned long, unsigned long, void *)
	?Observer@COmxInputPort@@IBEPAVMMdfInputPortObserver@@XZ @ 56 NONAME ; class MMdfInputPortObserver * COmxInputPort::Observer(void) const
	?Observer@COmxOutputPort@@IBEPAVMMdfOutputPortObserver@@XZ @ 57 NONAME ; class MMdfOutputPortObserver * COmxOutputPort::Observer(void) const
	?Observer@COmxProcessingUnit@@IAEPBVMMdfProcessingUnitObserver@@XZ @ 58 NONAME ; class MMdfProcessingUnitObserver const * COmxProcessingUnit::Observer(void)
	?OmxAllocateBufferL@COmxProcessingUnit@@QAEPAVCMMFBuffer@@KK@Z @ 59 NONAME ; class CMMFBuffer * COmxProcessingUnit::OmxAllocateBufferL(unsigned long, unsigned long)
	?OmxEmptyThisBuffer@COmxProcessingUnit@@QAEHPBVCMMFBuffer@@PAVMOmxInputPortCallbacks@@@Z @ 60 NONAME ; int COmxProcessingUnit::OmxEmptyThisBuffer(class CMMFBuffer const *, class MOmxInputPortCallbacks *)
	?OmxFillThisBuffer@COmxProcessingUnit@@QAEHPAVCMMFBuffer@@PAVMOmxOutputPortCallbacks@@@Z @ 61 NONAME ; int COmxProcessingUnit::OmxFillThisBuffer(class CMMFBuffer *, class MOmxOutputPortCallbacks *)
	?OmxFreeBuffer@COmxProcessingUnit@@QAEHPAVCMMFBuffer@@@Z @ 62 NONAME ; int COmxProcessingUnit::OmxFreeBuffer(class CMMFBuffer *)
	?OmxGetParameter@COmxProcessingUnit@@QAEHW4OMX_INDEXTYPE@@PAX@Z @ 63 NONAME ; int COmxProcessingUnit::OmxGetParameter(enum OMX_INDEXTYPE, void *)
	?OmxSendCommand@COmxProcessingUnit@@QAEHW4OMX_COMMANDTYPE@@KPAX@Z @ 64 NONAME ; int COmxProcessingUnit::OmxSendCommand(enum OMX_COMMANDTYPE, unsigned long, void *)
	?OmxSetParameter@COmxProcessingUnit@@QAEHW4OMX_INDEXTYPE@@PAX@Z @ 65 NONAME ; int COmxProcessingUnit::OmxSetParameter(enum OMX_INDEXTYPE, void *)
	?OmxUseBuffer@COmxProcessingUnit@@QAEHPAVCMMFBuffer@@K@Z @ 66 NONAME ; int COmxProcessingUnit::OmxUseBuffer(class CMMFBuffer *, unsigned long)
	?Pause@COmxProcessingUnit@@UAEHXZ @ 67 NONAME ; int COmxProcessingUnit::Pause(void)
	?SetPuState@COmxProcessingUnit@@IAEXW4TProcessingUnitState@@@Z @ 68 NONAME ; void COmxProcessingUnit::SetPuState(enum TProcessingUnitState)
	?State@COmxProcessingUnit@@UAE?AW4TProcessingUnitState@@XZ @ 69 NONAME ; enum TProcessingUnitState COmxProcessingUnit::State(void)
	?Stop@COmxProcessingUnit@@UAEXXZ @ 70 NONAME ; void COmxProcessingUnit::Stop(void)
	?MipoDisconnectTunnelComplete@COmxOutputPort@@UAEXPBVMMdfInputPort@@H@Z @ 71 NONAME ; void COmxOutputPort::MipoDisconnectTunnelComplete(class MMdfInputPort const *, int)
	?MipoRestartTunnelComplete@COmxOutputPort@@UAEXPBVMMdfInputPort@@H@Z @ 72 NONAME ; void COmxOutputPort::MipoRestartTunnelComplete(class MMdfInputPort const *, int)
	?MipoWriteDataComplete@COmxOutputPort@@UAEXPBVMMdfInputPort@@PAVCMMFBuffer@@H@Z @ 73 NONAME ; void COmxOutputPort::MipoWriteDataComplete(class MMdfInputPort const *, class CMMFBuffer *, int)

